@@ -1,27 +1,13 @@
-/*=============================================================================
-
-    This file is part of ARB.
-
-    ARB is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    ARB is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with ARB; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
+/*
     Copyright (C) 2012 Fredrik Johansson
 
-******************************************************************************/
+    This file is part of Arb.
+
+    Arb is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
 
 #ifndef ACB_H
 #define ACB_H
@@ -32,6 +18,7 @@
 #define ACB_INLINE static __inline__
 #endif
 
+#include <stdio.h>
 #include "arf.h"
 #include "arb.h"
 
@@ -61,33 +48,10 @@ acb_init(acb_t x)
     arb_init(acb_imagref(x));
 }
 
-ACB_INLINE void
-acb_clear(acb_t x)
-{
-    arb_clear(acb_realref(x));
-    arb_clear(acb_imagref(x));
-}
+void acb_clear(acb_t x);
 
-ACB_INLINE acb_ptr
-_acb_vec_init(slong n)
-{
-    slong i;
-    acb_ptr v = (acb_ptr) flint_malloc(sizeof(acb_struct) * n);
-
-    for (i = 0; i < n; i++)
-        acb_init(v + i);
-
-    return v;
-}
-
-ACB_INLINE void
-_acb_vec_clear(acb_ptr v, slong n)
-{
-    slong i;
-    for (i = 0; i < n; i++)
-        acb_clear(v + i);
-    flint_free(v);
-}
+acb_ptr _acb_vec_init(slong n);
+void _acb_vec_clear(acb_ptr v, slong n);
 
 ACB_INLINE arb_ptr acb_real_ptr(acb_t z) { return acb_realref(z); }
 ACB_INLINE arb_ptr acb_imag_ptr(acb_t z) { return acb_imagref(z); }
@@ -128,6 +92,12 @@ acb_is_int(const acb_t z)
     return arb_is_zero(acb_imagref(z)) && arb_is_int(acb_realref(z));
 }
 
+ACB_INLINE int
+acb_is_int_2exp_si(const acb_t z, slong e)
+{
+    return arb_is_zero(acb_imagref(z)) && arb_is_int_2exp_si(acb_realref(z), e);
+}
+
 ACB_INLINE void
 acb_zero(acb_t z)
 {
@@ -184,6 +154,12 @@ acb_equal(const acb_t x, const acb_t y)
            arb_equal(acb_imagref(x), acb_imagref(y));
 }
 
+ACB_INLINE int
+acb_equal_si(const acb_t x, slong y)
+{
+    return arb_equal_si(acb_realref(x), y) && arb_is_zero(acb_imagref(x));
+}
+
 ACB_INLINE int
 acb_eq(const acb_t x, const acb_t y)
 {
@@ -415,8 +391,19 @@ acb_get_rad_ubound_arf(arf_t u, const acb_t z, slong prec)
     arf_mul_2exp_si(u, u, 1);
 }
 
+ACB_INLINE void
+acb_union(acb_t res, const acb_t x, const acb_t y, slong prec)
+{
+    arb_union(acb_realref(res), acb_realref(x), acb_realref(y), prec);
+    arb_union(acb_imagref(res), acb_imagref(x), acb_imagref(y), prec);
+}
+
 void acb_arg(arb_t r, const acb_t z, slong prec);
 
+void acb_sgn(acb_t res, const acb_t z, slong prec);
+
+void acb_csgn(arb_t res, const acb_t z);
+
 ACB_INLINE void
 acb_add(acb_t z, const acb_t x, const acb_t y, slong prec)
 {
@@ -693,6 +680,7 @@ void acb_log1p(acb_t r, const acb_t z, slong prec);
 void acb_exp(acb_t r, const acb_t z, slong prec);
 void acb_exp_pi_i(acb_t r, const acb_t z, slong prec);
 void acb_exp_invexp(acb_t r, acb_t s, const acb_t z, slong prec);
+void acb_expm1(acb_t r, const acb_t z, slong prec);
 
 void acb_sin(acb_t r, const acb_t z, slong prec);
 void acb_cos(acb_t r, const acb_t z, slong prec);
@@ -752,6 +740,9 @@ void acb_sin_cos_pi(acb_t s, acb_t c, const acb_t z, slong prec);
 void acb_tan_pi(acb_t r, const acb_t z, slong prec);
 void acb_cot_pi(acb_t r, const acb_t z, slong prec);
 
+void acb_sinc(acb_t res, const acb_t z, slong prec);
+void acb_sinc_pi(acb_t res, const acb_t z, slong prec);
+
 void acb_pow_arb(acb_t z, const acb_t x, const arb_t y, slong prec);
 void acb_pow(acb_t r, const acb_t x, const acb_t y, slong prec);
 
@@ -789,6 +780,8 @@ void acb_zeta(acb_t z, const acb_t s, slong prec);
 void acb_hurwitz_zeta(acb_t z, const acb_t s, const acb_t a, slong prec);
 void acb_polygamma(acb_t res, const acb_t s, const acb_t z, slong prec);
 
+void acb_bernoulli_poly_ui(acb_t res, ulong n, const acb_t x, slong prec);
+
 void acb_log_barnes_g(acb_t res, const acb_t z, slong prec);
 void acb_barnes_g(acb_t res, const acb_t z, slong prec);
 
@@ -798,6 +791,20 @@ void acb_polylog_si(acb_t w, slong s, const acb_t z, slong prec);
 void acb_agm1(acb_t m, const acb_t z, slong prec);
 void acb_agm1_cpx(acb_ptr m, const acb_t z, slong len, slong prec);
 
+#define ACB_LAMBERTW_LEFT 2
+#define ACB_LAMBERTW_MIDDLE 4
+
+void acb_lambertw_asymp(acb_t res, const acb_t z, const fmpz_t k, slong L, slong M, slong prec);
+int acb_lambertw_check_branch(const acb_t w, const fmpz_t k, slong prec);
+void acb_lambertw_bound_deriv(mag_t res, const acb_t z, const acb_t ez1, const fmpz_t k);
+void acb_lambertw(acb_t res, const acb_t z, const fmpz_t k, int flags, slong prec);
+
+ACB_INLINE void
+acb_sqr(acb_t res, const acb_t val, slong prec)
+{
+    acb_mul(res, val, val, prec);
+}
+
 /*
 TBD
 
@@ -984,16 +991,36 @@ _acb_vec_scalar_div_fmpz(acb_ptr res, acb_srcptr vec, slong len, const fmpz_t c,
 }
 
 ACB_INLINE void
-acb_print(const acb_t x)
+acb_fprint(FILE * file, const acb_t x)
 {
-    flint_printf("(");
-    arb_print(acb_realref(x));
-    flint_printf(", ");
-    arb_print(acb_imagref(x));
-    flint_printf(")");
+    flint_fprintf(file, "(");
+    arb_fprint(file, acb_realref(x));
+    flint_fprintf(file, ", ");
+    arb_fprint(file, acb_imagref(x));
+    flint_fprintf(file, ")");
 }
 
-void acb_printd(const acb_t z, slong digits);
+ACB_INLINE void
+acb_print(const acb_t x)
+{
+    acb_fprint(stdout, x);
+}
+
+void acb_fprintd(FILE * file, const acb_t z, slong digits);
+
+ACB_INLINE void
+acb_printd(const acb_t z, slong digits)
+{
+    acb_fprintd(stdout, z, digits);
+}
+
+void acb_fprintn(FILE * fp, const acb_t z, long digits, ulong flags);
+
+ACB_INLINE void
+acb_printn(const acb_t x, slong digits, ulong flags)
+{
+    acb_fprintn(stdout, x, digits, flags);
+}
 
 void acb_randtest(acb_t z, flint_rand_t state, slong prec, slong mag_bits);
 
@@ -1113,6 +1140,28 @@ _acb_vec_get_unique_fmpz_vec(fmpz * res,  acb_srcptr vec, slong len)
 /* sort complex numbers in a nice-to-display order */
 void _acb_vec_sort_pretty(acb_ptr vec, slong len);
 
+/* roots of unity */
+void acb_unit_root(acb_t res, ulong order, slong prec);
+void _acb_vec_unit_roots(acb_ptr z, slong len, slong prec);
+
+ACB_INLINE slong
+acb_allocated_bytes(const acb_t x)
+{
+    return arb_allocated_bytes(acb_realref(x)) + arb_allocated_bytes(acb_imagref(x));
+}
+
+ACB_INLINE slong
+_acb_vec_allocated_bytes(acb_srcptr vec, slong len)
+{
+    return _arb_vec_allocated_bytes((arb_srcptr) vec, 2 * len);
+}
+
+ACB_INLINE double
+_acb_vec_estimate_allocated_bytes(slong len, slong prec)
+{
+    return 2 * _arb_vec_estimate_allocated_bytes(len, prec);
+}
+
 #ifdef __cplusplus
 }
 #endif
