@@ -1,35 +1,19 @@
-/*=============================================================================
-
-    This file is part of ARB.
-
-    ARB is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    ARB is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with ARB; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
+/*
     Copyright (C) 2014 Fredrik Johansson
 
-******************************************************************************/
+    This file is part of Arb.
+
+    Arb is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
 
 #include "arb.h"
 
 /* See verify_taylor.py for code to generate tables and
    proof of correctness */
 
-int _arf_get_integer_mpn(mp_ptr y, mp_srcptr x, mp_size_t xn, slong exp);
-
 #define TMP_ALLOC_LIMBS(size) TMP_ALLOC((size) * sizeof(mp_limb_t))
 
 #define ODD_RECIPROCAL_TAB_SIZE 256
@@ -577,7 +561,7 @@ void _arb_atan_taylor_rs(mp_ptr y, mp_limb_t * error,
     if (N >= ODD_RECIPROCAL_TAB_SIZE)
     {
         flint_printf("_arb_atan_taylor_rs: N too large!\n");
-        abort();
+        flint_abort();
     }
 
     if (N <= 2)
@@ -671,7 +655,7 @@ void _arb_atan_taylor_rs(mp_ptr y, mp_limb_t * error,
                 if (s[xn + 1] != 0)
                 {
                     flint_printf("bad division!\n");
-                    abort();
+                    flint_abort();
                 }
 
                 /* subtract 1 */
