@@ -1,27 +1,13 @@
-/*=============================================================================
-
-    This file is part of ARB.
-
-    ARB is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    ARB is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with ARB; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
+/*
     Copyright (C) 2013 Fredrik Johansson
 
-******************************************************************************/
+    This file is part of Arb.
+
+    Arb is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
 
 #include "arb.h"
 #include "acb.h"
@@ -57,7 +43,7 @@ choose_n(double log2z, double argz, int digamma, slong prec)
         if (boundn > 1)
         {
             flint_printf("exception: gamma_stirling_choose_param failed to converge\n");
-            abort();
+            flint_abort();
         }
     }
 }
@@ -650,7 +636,7 @@ arb_gamma_small_frac(arb_t y, unsigned int p, unsigned int q, slong prec)
     else
     {
         flint_printf("small fraction not implemented!\n");
-        abort();
+        flint_abort();
     }
 }
 
@@ -683,7 +669,7 @@ arb_gamma_fmpq_outward(arb_t y, const fmpq_t x, slong prec)
     if (!fmpz_fits_si(n))
     {
         flint_printf("gamma: too large fmpq to reduce to 0!\n");
-        abort();
+        flint_abort();
     }
 
     m = fmpz_get_si(n);
@@ -699,7 +685,7 @@ arb_gamma_fmpq_outward(arb_t y, const fmpq_t x, slong prec)
     else
     {
         flint_printf("arb_gamma_fmpq: invalid fraction\n");
-        abort();
+        flint_abort();
     }
 
     /* argument reduction */
@@ -776,6 +762,7 @@ _arb_gamma(arb_t y, const arb_t x, slong prec, int inverse)
     int reflect;
     slong r, n, wp;
     arb_t t, u, v;
+    double acc;
 
     if (arb_is_exact(x))
     {
@@ -813,8 +800,13 @@ _arb_gamma(arb_t y, const arb_t x, slong prec, int inverse)
         }
     }
 
-    wp = prec + FLINT_BIT_COUNT(prec);
-
+    /* todo: for large x (if exact or accurate enough), increase precision */
+    acc = arb_rel_accuracy_bits(x);
+    acc = FLINT_MAX(acc, 0);
+    wp = FLINT_MIN(prec, acc + 20);
+    wp = FLINT_MAX(wp, 2);
+    wp = wp + FLINT_BIT_COUNT(wp);
+ 
     arb_gamma_stirling_choose_param(&reflect, &r, &n, x, 1, 0, wp);
 
     arb_init(t);
