@@ -1,37 +1,18 @@
-/*=============================================================================
-
-    This file is part of ARB.
-
-    ARB is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    ARB is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with ARB; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
+/*
     Copyright (C) 2012-2014 Fredrik Johansson
 
-******************************************************************************/
+    This file is part of Arb.
 
+    Arb is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
+
+#include "flint/mpn_extras.h"
 #include "arb.h"
-#include "mpn_extras.h"
 
 #define TMP_ALLOC_LIMBS(__n) TMP_ALLOC((__n) * sizeof(mp_limb_t))
-
-int _arf_get_integer_mpn(mp_ptr y, mp_srcptr x, mp_size_t xn, slong exp);
-
-int _arf_set_mpn_fixed(arf_t z, mp_srcptr xp, mp_size_t xn, mp_size_t fixn, int negative, slong prec);
-
 #define MAGLIM(prec) FLINT_MAX(65536, (4*prec))
 
 static void
@@ -462,7 +443,7 @@ arb_sin_cos_arf_new(arb_t zsin, arb_t zcos, const arf_t x, slong prec)
     if (want_sin)
     {
         inexact = _arf_set_mpn_fixed(arb_midref(zsin), sinptr,
-            wn, wn, sinnegative, prec);
+            wn, wn, sinnegative, prec, ARB_RND);
         if (inexact)
             arf_mag_add_ulp(arb_radref(zsin),
                 arb_radref(zsin), arb_midref(zsin), prec);
@@ -471,7 +452,7 @@ arb_sin_cos_arf_new(arb_t zsin, arb_t zcos, const arf_t x, slong prec)
     if (want_cos)
     {
         inexact = _arf_set_mpn_fixed(arb_midref(zcos), cosptr,
-            wn, wn, cosnegative, prec);
+            wn, wn, cosnegative, prec, ARB_RND);
         if (inexact)
             arf_mag_add_ulp(arb_radref(zcos),
                 arb_radref(zcos), arb_midref(zcos), prec);
