@@ -1,27 +1,13 @@
-/*=============================================================================
-
-    This file is part of ARB.
-
-    ARB is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    ARB is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with ARB; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
-
-=============================================================================*/
-/******************************************************************************
-
+/*
     Copyright (C) 2014 Fredrik Johansson
 
-******************************************************************************/
+    This file is part of Arb.
+
+    Arb is free software: you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 2.1 of the License, or
+    (at your option) any later version.  See <http://www.gnu.org/licenses/>.
+*/
 
 #include <math.h>
 #include "arb_poly.h"
@@ -121,7 +107,7 @@ _mag_vec_get_fmpz_2exp_blocks(fmpz * coeffs,
 
     maxheight = ALPHA * MAG_BITS + BETA;
     if (maxheight > DOUBLE_BLOCK_MAX_HEIGHT)
-        abort();
+        flint_abort();
 
     for (i = 0; i < len; i++)
     {
@@ -205,14 +191,14 @@ _mag_vec_get_fmpz_2exp_blocks(fmpz * coeffs,
                 fmpz_sub_ui(t, t, MAG_BITS); /* bottom exponent */
                 s = _fmpz_sub_small(t, exps + i);
 
-                if (s < 0) abort(); /* Bug catcher */
+                if (s < 0) flint_abort(); /* Bug catcher */
 
                 fmpz_set_ui(coeffs + j, man);
                 fmpz_mul_2exp(coeffs + j, coeffs + j, s);
                 c = man;
                 c = ldexp(c, s - DOUBLE_BLOCK_SHIFT);
                 if (c < 1e-150 || c > 1e150) /* Bug catcher */
-                    abort();
+                    flint_abort();
                 dblcoeffs[j] = c;
             }
         }
@@ -322,7 +308,7 @@ _arb_vec_get_fmpz_2exp_blocks(fmpz * coeffs, fmpz * exps,
                 fmpz_mul_ui(t, scale, j);
                 fmpz_sub(t, bot, t);
                 s = _fmpz_sub_small(t, exps + i);
-                if (s < 0) abort(); /* Bug catcher */
+                if (s < 0) flint_abort(); /* Bug catcher */
                 fmpz_mul_2exp(coeffs + j, coeffs + j, s);
             }
         }
